@@ -411,7 +411,7 @@ final class CodeCoverage
      */
     public function driverIsPcov(): bool
     {
-        return $this->driver->isPcov();
+        return isset($this->driver) && $this->driver->isPcov();
     }
 
     /**
@@ -419,7 +419,7 @@ final class CodeCoverage
      */
     public function driverIsXdebug(): bool
     {
-        return $this->driver->isXdebug();
+        return isset($this->driver) && $this->driver->isXdebug();
     }
 
     /**
